@@ -28,7 +28,18 @@ case "$1" in
         fi
         chown benno.benno /etc/benno/rest.secret
         chmod 0640 /etc/benno/rest.secret
+
     fi
+
+    # update jetty.xml < 2.10.0
+    grep -q "org.eclipse.jetty.server.nio.SelectChannelConnector" /etc/benno/jetty.xml && \
+    (
+        /bin/mv /etc/benno/jetty.xml /etc/benno/jetty-v28.xml
+        zcat /usr/share/doc/benno-rest/contrib/convert-config.gz | perl - /etc/benno/jetty-v28.xml > /etc/benno/jetty.xml
+        chown bennorest.benno /etc/benno/jetty.xml
+        chmod 0640 /etc/benno/jetty.xml
+    )
+
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
